pub enum FfiError {
VaultDoesNotSupportPersistence = 1,
ErrorCreatingFilesystemVault = 2,
InvalidParam = 3,
EntryNotFound = 4,
UnknownPublicKeyType = 5,
InvalidString = 6,
BufferTooSmall = 7,
InvalidPublicKey = 8,
VaultNotFound = 9,
OwnershipError = 10,
UnexpectedPanic = 11,
}Expand description
Represents the failures that can occur in an Ockam FFI Vault.
Variants
VaultDoesNotSupportPersistence = 1
Persistence is not supported for this Vault implementation.
ErrorCreatingFilesystemVault = 2
An underlying filesystem error prevented Vault creation.
InvalidParam = 3
Invalid parameter.
EntryNotFound = 4
Entry not found.
UnknownPublicKeyType = 5
Unknown public key type.
InvalidString = 6
Invalid string.
BufferTooSmall = 7
Buffer is too small.
InvalidPublicKey = 8
A public key is invalid.
VaultNotFound = 9
No such Vault.
OwnershipError = 10
Ownership error.
UnexpectedPanic = 11
Caught a panic (which would be UB if we let it unwind across the FFI).